import React, { useEffect } from "react";
import dayjs from "dayjs";
import { EditOutlined } from "@ant-design/icons";
import { Row, Col, Card, Tabs, Button, Form, Input, DatePicker } from "antd";
import { ModalForm } from "@ant-design/pro-components";
import { postTaCheck, putTaCheck } from "@/service/tacheck";
import { useNavigate } from "react-router-dom";
import Percent from "@/components/Percent";
import SurverForm from "./SurveyForm";

export default (props) => {
  const navigate = useNavigate();
  const { checkInfo, onChange, onTabChange } = props;

  const [open, setOpen] = React.useState(false);
  const [form] = Form.useForm();

  const onEdit = () => {
    setOpen(true);
  };

  const title = checkInfo ? (
    checkInfo.title
  ) : (
    <div onClick={onEdit}>点击编辑创建</div>
  );
  const dateStr = checkInfo
    ? `${checkInfo.startDate} ~ ${checkInfo.endDate}`
    : "";

  const onFinish = async (values) => {
    const data = {
      ...values,
      startDate: dayjs(values.startDate).format("YYYY-MM-DD"),
      endDate: dayjs(values.endDate).format("YYYY-MM-DD"),
    };

    if (!checkInfo) {
      const res = await postTaCheck(data);
      onChange(res);
      console.log(123);
    } else {
      const res = await putTaCheck(checkInfo.checkId, data);
      onChange(res);
    }
    return true;
  };



  React.useEffect(() => {
    if (checkInfo) {
      form.setFieldsValue({
        ...checkInfo,
        startDate: dayjs(checkInfo.startDate),
        endDate: dayjs(checkInfo.endDate),
      });
    }
  }, [checkInfo]);

  return (
    <Card
      bodyStyle={{ padding: 0 }}
      title={
        <div style={{ fontWeight: "normal" }}>
          <span style={{ display: "inline-block", fontSize: "1.6em" }}>
            {title}
          </span>
          <span style={{ display: "inline-block", margin: "0 1em" }}>
            {dateStr}
          </span>
        </div>
      }
      extra={
        <Button type="link" icon={<EditOutlined />} onClick={onEdit}>
          编辑
        </Button>
      }
    >
      <Tabs
        defaultActiveKey="1"
        onChange={onTabChange}
        tabBarStyle={{ margin: "0 2em" }}
        items={[
          {
            label: "实地测评",
            key: "1",
          },
          {
            label: (
              <div>
                <span>调查问卷</span>
                <SurverForm checkId={checkInfo?.checkId} />
              </div>
            ),
            key: "2",
          },
        ]}
      />
      <ModalForm
        title="测评维护"
        open={open}
        width={480}
        form={form}
        onFinish={onFinish}
        onOpenChange={setOpen}
      >
        <Form.Item name="title" label="测评名称" required>
          <Input placeholder="请输入测评名称" />
        </Form.Item>
        <Form.Item name="startDate" label="开始时间" required>
          <DatePicker placeholder="请选择" style={{ width: "100%" }} />
        </Form.Item>
        <Form.Item name="endDate" label="结束时间" required>
          <DatePicker placeholder="请选择" style={{ width: "100%" }} />
        </Form.Item>
        <Row gutter={24}>
          <Col span={12}>
            <Form.Item name="locScorePercent" label="实地占比 (%)" required>
              <Percent placeholder="请设置" style={{ width: "100%" }} />
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item name="surveyScorePercent" label="问卷占比 (%)" required>
              <Percent placeholder="请设置" style={{ width: "100%" }} />
            </Form.Item>
          </Col>
        </Row>
      </ModalForm>
    </Card>
  );
};
