import React from "react";
import { Link } from "react-router-dom";
import useBool from "@/utils/hooks/useBool";
import { Table, Space, Button, Row, Col, Card } from "antd";
import { getTaCheckItem, exportTaCheckItem } from "@/service/tacheckitem";
import QuList from "./QuList";
import LocForm from "./LocForm";
import styles from "./style.module.less";

export default (props) => {
  const { checkId } = props;

  const [list, setList] = React.useState([]);
  const [curItem, setCurItem] = React.useState();
  const [loading, startLoading, stopLoading] = useBool();
  const [open, setOpen] = React.useState(false);
  const [expLoading, startExpLoading, stopExpLoading] = useBool();

  const columns = [
    {
      title: "点位名称",
      dataIndex: "name",
      key: "name",
    },
    {
      title: "分值",
      dataIndex: "fullScore",
    },
    {
      title: "已收/计划数",
      dataIndex: "num",
      key: "num",
      render: (_, row) => {
        return (
          <Space>
            <span>
              <Link
                to={`/checkAnswer/loc?checkId=${row.checkId}&typeId=${row.typeId}&back=true`}
              >
                {row.answerNum || 0}
              </Link>
            </span>
            <span>/</span>
            <span>{row.num || 0}</span>
          </Space>
        );
      },
    },
    {
      title: "小计",
      dataIndex: "fullScore",
      key: "fullScore",
      render: (_, row) =>
        row.fullScore ? Number(row.fullScore * (row.num || 0)).toFixed(2) : "-",
    },
    {
      title: "测评得分",
      dataIndex: "score",
      key: "score",
    },
    {
      title: "操作",
      key: "options",
      width: 100,
      render: (_, row) => {
        return (
          <Space>
            <Button type="link" onClick={() => onEdit(row)}>
              编辑
            </Button>
          </Space>
        );
      },
    },
  ];

  const summary = React.useMemo(() => {
    let fullScore = 0;
    let answerNum = 0;
    let num = 0;
    let score = 0;
    let subtotal = 0;

    list.forEach((x) => {
      fullScore += x.fullScore || 0;
      answerNum += x.answerNum || 0;
      num += x.num || 0;
      score += x.score || 0;
      subtotal += (x.fullScore || 0) * (x.num || 0);
    });

    return {
      fullScore,
      answerNum,
      num,
      score,
      subtotal: Number(subtotal).toFixed(2),
    };
  }, [list]);

  const queryList = React.useCallback(() => {
    if (checkId) {
      startLoading();
      getTaCheckItem({ pageSize: 500, checkId, itemType: "loc" })
        .then((res) => {
          setList(res.records || []);
          stopLoading();
        })
        .catch(() => {
          stopLoading();
        });
    }
  }, [checkId]);

  const onEdit = (row) => {
    setCurItem(row);
    setOpen(true);
  };

  const onExport = () => {
    startExpLoading();
    exportTaCheckItem(checkId)
      .then(() => {
        stopExpLoading();
      })
      .catch(() => {
        stopExpLoading();
      });
  };

  const onChange = (item) => {
    const newList = list.map((x) => (x.itemId === item.itemId ? item : x));
    setList(newList);
  };

  const onQuChange = () => {
    queryList();
  };

  const getRowClassName = (row) => {
    return [
      styles["yz-table-row"],
      row.itemId == curItem?.itemId ? styles.active : false,
    ]
      .filter(Boolean)
      .join(" ");
  };

  React.useEffect(() => {
    queryList();
  }, [queryList]);

  const onSync = () => {
    // getTaCheckItem({ pageSize: 500, checkId, itemType: "loc" }).then((res) => {
    // setList(res.records || []);
    // });
  };
  return (
    <Row gutter={24}>
      <Col span={12}>
        <Card
          extra={
            <>
              {checkId ? (
                <Button
                  style={{ marginRight: "20px" }}
                  type="primary"
                  onClick={onSync}
                >
                  同步点位
                </Button>
              ) : (
                ""
              )}

              <Button loading={expLoading} type="primary" onClick={onExport}>
                导出
              </Button>
            </>
          }
        >
          <Table
            sticky
            summary={() => (
              <Table.Summary fixed="top">
                <Table.Summary.Row style={{ fontWeight: "bolder" }}>
                  <Table.Summary.Cell index={0}>合计</Table.Summary.Cell>
                  <Table.Summary.Cell index={1}>
                    {summary.fullScore}
                  </Table.Summary.Cell>
                  <Table.Summary.Cell
                    index={2}
                  >{`${summary.answerNum} / ${summary.num}`}</Table.Summary.Cell>
                  <Table.Summary.Cell index={3}>
                    {summary.subtotal}
                  </Table.Summary.Cell>
                  <Table.Summary.Cell index={4}>
                    {summary.score}
                  </Table.Summary.Cell>
                </Table.Summary.Row>
              </Table.Summary>
            )}
            rowKey="typeId"
            loading={loading}
            columns={columns}
            dataSource={list}
            pagination={false}
            rowClassName={getRowClassName}
            onRow={(row) => ({
              onClick: () => setCurItem(row),
            })}
          />
          <LocForm
            checkId={checkId}
            itemId={curItem?.itemId}
            open={open}
            checkItem={curItem}
            onOpenChange={setOpen}
            onChange={onChange}
          />
        </Card>
      </Col>
      <Col span={12}>
        <QuList itemId={curItem?.itemId} onChange={onQuChange} />
      </Col>
    </Row>
  );
};
